ReadError

Enum ReadError 

pub enum ReadError {
    InvalidTag(u8),
    MissingNullTerminator,
    InvalidUtf8,
    InvalidBoolValue,
    InvalidFloatLength,
    InvalidFdLength,
    TimestampOutOfRange,
    InvalidSubfield,
    InvalidKeyValuePair,
    InvalidFdNumber(u32),
}
An error while reading argdata.

Variants



InvalidTag(u8)

The data contained the given tag, which doesn’t correspond to any known type.



MissingNullTerminator

The data represents a string, but it wasn’t null-terminated.



InvalidUtf8

The data represents a string, but it contained invalid UTF-8.



InvalidBoolValue

The data represents a boolean, but it contained a value other than ‘false’ or ‘true’.



InvalidFloatLength

The data represents a float, but wasn’t exactly 64 bits.



InvalidFdLength

The data represents a file descriptor, but wasn’t exactly 32 bits.



TimestampOutOfRange

The data represents a timestamp that does not fit in a Timespec.



InvalidSubfield

The data contains a subfield (of a map or seq) with an incomplete or too large length.



InvalidKeyValuePair

The data contains a map with an incomplete key-value pair.



InvalidFdNumber(u32)

The data represents a file descriptor that doesn’t exist. (Possibly because there were no file descriptors ‘attached’ to the argdata value at all.)